commands/rename_command_runner library
File: rename_command_runner.dart Project: rename Author: Onat Cipli Created Date: 24.09.2023 Description: This file defines RenameCommandRunner for the rename project and its commands, options etc.
Classes
- GetLongVersionCommand
- GetShortVersionCommand
- PlatformFileEditorCommand
- PlatformFileEditorCommand is an abstract class that extends the Command class. It provides a base for all platform file editor commands.
- ReversionCommandRunner
- ReversionCommandRunner is responsible for running the rename command in the CLI tool. It extends the CommandRunner class and overrides some of its methods.
- SetLongVersionCommand
- SetPlatformFileEditorCommand
- SetPlatformFileEditorCommand is an abstract class that extends the PlatformFileEditorCommand class. It provides a base for all set platform file editor commands.
- SetShortVersionCommand