ReversionCommandRunner constructor
ReversionCommandRunner()
Constructor for ReversionCommandRunner. It initializes the super class with the name of the command and its description.
Implementation
ReversionCommandRunner()
: super(
'reversion',
'A CLI tool that helps for renaming in Flutter projects.',
) {
argParser.addFlag(
'version',
abbr: 'v',
negatable: false,
);
addCommand(GetLongVersionCommand());
addCommand(GetShortVersionCommand());
addCommand(SetLongVersionCommand());
addCommand(SetShortVersionCommand());
}